//
//  InterfaceController.swift
//  mapCoreLocation WatchKit Extension
//
//  Created by yoshiyuki oshige on 2015/04/01.
//  Copyright (c) 2015年 yoshiyuki oshige. All rights reserved.
//

import WatchKit
import Foundation
import CoreLocation


class InterfaceController: WKInterfaceController, CLLocationManagerDelegate {
    
    // MapをOutlet接続する
    @IBOutlet weak var myMap: WKInterfaceMap!
    // CLLocationManagerクラスのインスタンスを作る
    let locationManager = CLLocationManager()
    
    override init() {
        super.init()
        
        // デリゲートにselfを設定する
        locationManager.delegate = self
        // ロケーションサービスを利用できる
        let locationServices = CLLocationManager.locationServicesEnabled()
        if locationServices {
            // 許可を確認
            let authorization = CLLocationManager.authorizationStatus()
            switch authorization {
            case .AuthorizedAlways, .AuthorizedWhenInUse:
                // 計測精度（数m）
                locationManager.desiredAccuracy = kCLLocationAccuracyBest
                // 更新距離間隔（10m移動で更新）
                locationManager.distanceFilter = 10
                // 更新をスタートする
                locationManager.startUpdatingLocation()
            default:
                println("authorizationStatus \(authorization.rawValue)")
            }
        } else {
            println("locationServicesEnabled \(locationServices.boolValue)")
        }
    }
    
    // CLLocationManagerDelegateの更新メソッド
    func locationManager(manager: CLLocationManager!,
        didUpdateToLocation newLocation: CLLocation!,
        fromLocation oldLocation: CLLocation!) {
            
            // 現在地の緯度／経度を取り出す
            let longitude = newLocation.coordinate.longitude
            let latitude = newLocation.coordinate.latitude
            let coordinate = CLLocationCoordinate2DMake(latitude, longitude)
            
            // 緯度／経度をMapの座標に変換する
            let center = MKMapPointForCoordinate(coordinate)
            // 指定座標を中心にした2km x 2kmの範囲
            let width:Double = 2000
            let height:Double = 2000
            let x = center.x-width/2
            let y = center.y-height/2
            let mapRect = MKMapRectMake(x, y, width, height)
            // アノテーションを取り除く
            myMap.removeAllAnnotations()
            // 指定座標に画像のアノテーションを貼る
            myMap.addAnnotation(coordinate, withImageNamed:"runPin", centerOffset:CGPointMake(0, -10))
            
            // 地図を表示する
            myMap.setVisibleMapRect(mapRect)
    }

    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        // Configure interface objects here.
    }

    override func willActivate() {
        // This method is called when watch view controller is about to be visible to user
        super.willActivate()
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
    }

}
