//
//  InterfaceController.swift
//  alphaAnimation WatchKit Extension
//
//  Created by yoshiyuki oshige on 2015/04/01.
//  Copyright (c) 2015年 yoshiyuki oshige. All rights reserved.
//

import WatchKit
import Foundation


class InterfaceController: WKInterfaceController {
    // インスタンス変数
    var timerObj:NSTimer?
    var goalValue:CGFloat = 1.0
    var currentValue:CGFloat = 1.0
    
    // イメージとOutlet接続する
    @IBOutlet weak var myFlower: WKInterfaceImage!
    
    // スイッチとAction接続する
    @IBAction func showHide(value: Bool) {
        if value {
            // フェードイン
            goalValue = 1.0
        } else {
            // フェードアウト
            goalValue = 0.0
        }
        // timerObjがnilでなければ破棄する
        if let timer = timerObj {
            timer.invalidate()
        }
        // タイマーを作る
        timerObj = NSTimer.scheduledTimerWithTimeInterval(0.1, target: self, selector: Selector("update"), userInfo: nil, repeats: true)
    }
    
    // タイマーで定期的に呼び出す
    func update(){
        // 徐々にゴールの値に近づける
        currentValue += (goalValue - currentValue)*2/5
        // イメージのアルファ値を変更する
        myFlower.setAlpha(currentValue)
        // ゴールとの差が0.1未満になったらタイマーを止める
        if abs(goalValue - currentValue) < 0.1 {
            // タイマーを破棄して止める
            timerObj?.invalidate()
            // ゴールの値で再設定する
            currentValue = goalValue
            myFlower.setAlpha(goalValue)
        }
    }
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        // Configure interface objects here.
    }

    override func willActivate() {
        // This method is called when watch view controller is about to be visible to user
        super.willActivate()
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
    }

}
