//
//  InterfaceController.swift
//  sizeAnimation WatchKit Extension
//
//  Created by yoshiyuki oshige on 2015/04/01.
//  Copyright (c) 2015年 yoshiyuki oshige. All rights reserved.
//

import WatchKit
import Foundation


class InterfaceController: WKInterfaceController {
    // インスタンス変数
    var timerObj:NSTimer?
    let maxValue:Int
    let barWidth:Int
    var currentValue:Int
    var goalValue:Int
    
    // 矢印のImageとOutlet接続する
    @IBOutlet weak var arrowImage: WKInterfaceImage!
    
    // イニシャライザ
    override init() {
        // インスタンス変数の初期化
        maxValue = 100
        barWidth = 135
        currentValue = 10
        goalValue = currentValue
    }
    
    // ボタンとAction接続する
    @IBAction func resetValue() {
        // バーの設定値を乱数で作る
        goalValue = Int(arc4random_uniform(UInt32(maxValue)))
        // timerObjがnilでなければ破棄する
        if let timer = timerObj {
            timer.invalidate()
        }
        // タイマーを作る
        timerObj = NSTimer.scheduledTimerWithTimeInterval(0.1, target: self, selector: Selector("update"), userInfo: nil, repeats: true)
    }
    
    // タイマーで定期的に呼び出す
    func update(){
        // 徐々にゴールの値に近づける
        currentValue += (goalValue - currentValue)*3/5
        // バーの長さを求める
        var tempWidth = barWidth * currentValue/maxValue
        // イメージの幅を変更する
        arrowImage.setWidth(CGFloat(tempWidth))
        // ゴールとの差が2未満になったらタイマーを止める
        if abs(goalValue - currentValue) < 2 {
            // タイマーを破棄して止める
            timerObj?.invalidate()
            // ゴールの値で再設定する
            currentValue = goalValue
            tempWidth = barWidth * goalValue/maxValue
            arrowImage.setWidth(CGFloat(tempWidth))
        }
    }
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        // Configure interface objects here.
    }

    override func willActivate() {
        // This method is called when watch view controller is about to be visible to user
        super.willActivate()
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
    }

}
