//
//  InterfaceController.swift
//  imageDynamicAnimation WatchKit Extension
//
//  Created by yoshiyuki oshige on 2015/04/01.
//  Copyright (c) 2015年 yoshiyuki oshige. All rights reserved.
//

import WatchKit
import Foundation


class InterfaceController: WKInterfaceController {
    // イメージをOutlet接続する
    @IBOutlet weak var myImage: WKInterfaceImage!
    
    // 複数のイメージからアニメーテッドイメージを作成する
    func makeAnimatedImageFromImages(name:String, count:Int) -> UIImage {
        // アニメーションのイメージを入れる配列を作る
        var images = Array<UIImage>()
        // 0番からcount番のイメージを作成する
        for n in 0...(count-1) {
            let imageName = name + String(n)
            // イメージを作成する
            let imageItem = UIImage(named: imageName)
            // 配列に追加する
            images.append(imageItem!)
        }
        // 配列に入っているイメージからアニメーテッドイメージを作成する
        let image = UIImage.animatedImageWithImages(images as [AnyObject], duration: 1)
        return image
    }
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        // アニメーテッドイメージを作る
        let animatedImage = makeAnimatedImageFromImages("frogKaiten", count:6)
        // WatchのImageにセットする
        myImage.setImage(animatedImage)
        // アニメーションのスタート（0スタート、6フレーム、0.5秒／回、無限回）
        myImage.startAnimatingWithImagesInRange(NSMakeRange(0, 6), duration: 0.5, repeatCount: 0)
    }

    override func willActivate() {
        // This method is called when watch view controller is about to be visible to user
        super.willActivate()
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
    }

}
