//
//  InterfaceController.swift
//  imageDynamicDrawAnimation WatchKit Extension
//
//  Created by yoshiyuki oshige on 2015/04/01.
//  Copyright (c) 2015年 yoshiyuki oshige. All rights reserved.
//

import WatchKit
import Foundation


class InterfaceController: WKInterfaceController {

    // イメージをOutlet接続する
    @IBOutlet weak var myImage: WKInterfaceImage!
    
    @IBAction func tapButton() {
        // 0〜100の乱数
        let percent = Int(arc4random_uniform(100))
        // パーセントのアニメーションを再生する
        myImage.startAnimatingWithImagesInRange(NSMakeRange(0, percent+1), duration: 0.5, repeatCount: 1)
    }
    
    // 0%から100%のアニメーテッドイメージを作る
    func makeAnimatedImage() -> UIImage {
        // アニメーションのイメージを入れる配列を作る
        var images = Array<UIImage>()
        // 0%から100%の円弧のイメージを作る
        for n in 0...100 {
            // 各パーセントの円弧イメージを作成する
            let imageItem = makeArcPathImage(Double(n))
            // 配列に追加する
            images.append(imageItem)
        }
        // 配列に入っているイメージからアニメーテッドイメージを作成する
        let image = UIImage.animatedImageWithImages(images as [AnyObject], duration: 1)
        return image
    }
    
    // パーセントに応じた円弧を描画してイメージを作る
    func makeArcPathImage(percent:Double)-> UIImage {
        /* コンテキストの用意 */
        let width:CGFloat = 100, height:CGFloat = 100
        // 透明、x2
        UIGraphicsBeginImageContextWithOptions(CGSizeMake(width, height), false, 2.0)
        let context = UIGraphicsGetCurrentContext()
        
        /* コンテキストに描画する */
        // 背景の円
        let center = CGPointMake(width/2, height/2)
        let radius = CGFloat(width/2)
        let circlePath = UIBezierPath(ovalInRect: CGRectMake(0, 0, width, height))
        // 塗り色
        CGContextSetRGBFillColor(context, 102/255.0, 255/255.0, 102/255.0, 1.0)
        // 円を塗る
        circlePath.fill()
        
        // 円弧を描く
        let start = CGFloat(-M_PI/2)
        let end = CGFloat(2*M_PI*percent/100.0 - M_PI/2)
        let arcPath = UIBezierPath(arcCenter: center, radius: radius-20,
            startAngle: start, endAngle: end, clockwise: true)
        // 線幅
        arcPath.lineWidth = 20
        // 線の端の形
        arcPath.lineCapStyle = kCGLineCapButt
        // 線の色
        CGContextSetRGBStrokeColor(context, 1.0, 0, 0, 1.0)
        // 線を引く
        arcPath.stroke()
        
        // パーセントの文字を描く
        let font = UIFont.boldSystemFontOfSize(28)
        let textFontAttributes = [ NSFontAttributeName: font, NSForegroundColorAttributeName: UIColor.whiteColor() ]
        let drawString = percent.description + "%"
        drawString.drawInRect(CGRectMake(20, 50, 100, 30),withAttributes: textFontAttributes)
        
        /* コンテキストからUIImageを作る */
        let image = UIGraphicsGetImageFromCurrentImageContext()
        UIGraphicsEndImageContext()
        return image
    }
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        // アニメーテッドイメージをイメージに設定する
        let animatedImage = makeAnimatedImage()
        myImage.setImage(animatedImage)
    }
    

    override func willActivate() {
        // This method is called when watch view controller is about to be visible to user
        super.willActivate()
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
    }

}
